<?php
/**
 *
 * Copyright © 2016 Magento. All rights reserved.
 * See COPYING.txt for license details.
 */

namespace FiloBlu\OrderAdditionalData\Model\Plugin;

/*
 * Add Order Increment ID to Shipment
 */
class ShipmentGet
{

    /** 
     * @var \Magento\Sales\Api\OrderRepositoryInterface 
     */
    protected $orderRepository;
    
    /** 
     * @var \Magento\Sales\Api\Data\ShipmentExtensionFactory
     */
    protected $shipmentExtensionFactory;
    
    
    /**
     * Init plugin
     *
     * @param \Magento\Sales\Api\OrderRepositoryInterface $orderRepository
     * @param \Magento\Sales\Api\Data\ShipmentExtensionFactory $shipmentExtensionFactory
     */
    public function __construct(
        \Magento\Framework\App\Helper\Context $context,    
        \Magento\Sales\Api\OrderRepositoryInterface $orderRepository,
        \Magento\Sales\Api\Data\ShipmentExtensionFactory $shipmentExtensionFactory
    ) {
        $this->orderRepository=$orderRepository;
        $this->shipmentExtensionFactory = $shipmentExtensionFactory;
    }

    /**
     * Add Order increment ID
     *
     * @param \Magento\Sales\Api\ShipmentRepositoryInterface $subject
     * @param \Magento\Sales\Api\Data\ShipmentInterface $shipment
     * @return \Magento\Sales\Api\Data\ShipmentInterface
     */
    public function afterGet(
        \Magento\Sales\Api\ShipmentRepositoryInterface $subject,
        \Magento\Sales\Api\Data\ShipmentInterface $shipment
    ) {
        $extensionAttributes = $shipment->getExtensionAttributes();
        $shipmentExtension = $extensionAttributes ? $extensionAttributes : $this->shipmentExtensionFactory->create();    
        $order_increment_id=$shipment->getData("order_increment_id");
        if ($order_increment_id==null) {
            $order=$this->orderRepository->get($shipment->getOrderId());
            $order_increment_id=$order->getIncrementId();
            $shipment->setData("order_increment_id", $order_increment_id);
            $shipment->save();
        }
        $shipmentExtension->setData("order_increment_id", $order_increment_id);
        $shipment->setExtensionAttributes($shipmentExtension);
        return $shipment;
    }
}
